import os
from flask import Flask
from flask_mail import Mail

app = Flask(__name__, instance_relative_config=True)
app.config.from_mapping(
    SECRET_KEY=os.environ.get('SECRET_KEY'),
    DATABASE=os.path.join(app.instance_path, 'upr_espera.sqlite'),
    MAIL_SERVER='smtp.googlemail.com',
    MAIL_PORT=587,
    MAIL_USE_TLS=1,
    MAIL_USERNAME=os.environ.get('MAIL_USERNAME'),
    MAIL_PASSWORD=os.environ.get('MAIL_PASSWORD'),
)
mail = Mail(app)

try:
    os.makedirs(app.instance_path)
except OSError:
    pass

from . import db
db.init_app(app)

from . import index
app.register_blueprint(index.bp)
app.add_url_rule('/', endpoint='index')

from . import admin_insert
app.register_blueprint(admin_insert.bp)
app.add_url_rule('/admin_insert', endpoint='admin_insert')

from . import admin_remove
app.register_blueprint(admin_remove.bp)
app.add_url_rule('/admin_remove', endpoint='admin_remove')
